
/*
** This is an example to show you how to use the MixerTypes.c functions.
** You just have to 'make MixerTypesTest' to compile it.
*/

#include<stdio.h>
#include<unistd.h>
#include"MixerTypes.h"
#include"ConfigLib.h"
#include"DspLib.h"

#define BFSZ 128000

void main(int argc, char **argv[])

{
  char buf[BFSZ];

  t_dsp*        my_dsp;
  t_main_mixer* main_mixer;    /* The main_mixer */
  t_mixer_elt*  my_first_elt;  /* A mixer element */
  t_mixer_elt*  my_second_elt; /* Another one */
  t_tempgmurf*  my_tempgmurf;  /* A temp file */
  t_mixer_info* my_mixerinfo;  /* Wave informations */
  t_gmurfrc*    my_gmurfrc;    /* Config File */

  /* Initializing the Config Structure with defaults 
     and initiaslzing DSPs */
  my_gmurfrc = gmurfrc_defaults();

  if (my_dsp == NULL) /* The DSP couldn't be initialized. */
    {
      printf("Error while initializing %s\n",my_gmurfrc->first_dsp->name);
      exit(-1);
    }

  /* Constructing the Main Mixer structure. */
  main_mixer = new_main_mixer(my_dsp,255,50,44100,32);

  /* Choosing the temp file for the first element. */
  my_tempgmurf = new_tempgmurf("../MiniProg/sound_test.wav");

  /* Choosing its properties. */
  my_mixerinfo = new_mixer_info(255,44100,50,0);

  /* Creating the first mixer element. */
  my_first_elt = add_mixer_elt(main_mixer,  my_dsp, my_tempgmurf, 
			       my_mixerinfo);

  /* Creating another mixer element... */
  my_tempgmurf = new_tempgmurf("../MiniProg/wav.wav");
  my_mixerinfo = new_mixer_info(255,44100,50,0);
  my_second_elt = add_mixer_elt(main_mixer, my_dsp, my_tempgmurf, 
				my_mixerinfo);

  /* Removing it... */
  remove_mixer_elt(main_mixer, my_second_elt);

  /*
  ** Processing
  */

  printf("%d\n",read(main_mixer->first_mixer_elt->tempgmurf->file, &buf, BFSZ));
  printf("%d\n",write(my_dsp->file, &buf, BFSZ));

  /*
  ** Freeing structures from memory
  */

  /* Freeing main mixer. */
  main_mixer_destroy(main_mixer);

  /* Freeing Config Structure and releases DSPs. */
  gmurfrc_destroy(my_gmurfrc);

}
